@@ -47,10 +47,8 @@ get_contrast_data_numeric <- function(model,
         lab <- "manual"
 
     } else if (isTRUE(variable$label %in% slopes)) {
-        # low <- x - h / 2
-        # high <- x + h / 2
-        low <- x
-        high <- x + h
+        low <- x - h / 2
+        high <- x + h / 2
         lab <- variable$label
 
     } else if (identical(variable$label, "exp(dY/dX)")) {
@@ -61,8 +59,19 @@ get_contrast_data_numeric <- function(model,
     # contrast_label is designed for categorical predictors
     # numeric contrasts first
     } else if (isTRUE(checkmate::check_numeric(variable$value, len = 1))) {
-        low <- x - variable$value / 2
-        high <- x + variable$value / 2
+
+        direction <- getOption("marginaleffects_contrast_direction", default = "forward")
+        if (isTRUE(direction == "center")) {
+            low <- x - variable$value / 2
+            high <- x + variable$value / 2
+        } else if (isTRUE(direction == "backward")) {
+            low <- x - variable$value
+            high <- x
+        } else {
+            low <- x
+            high <- x + variable$value
+        }
+
         # wrap in parentheses, unless mean() because there are already parentheses
         # important to display ratios of x+1, etc.
         # label should not be `(mpg+1) - mpg` because that is misleading for centered contrast
@@ -72,12 +81,6 @@ get_contrast_data_numeric <- function(model,
             lab <- sprintf("mean(+%s)", variable$value)
         }
 
-    # custom vector
-    } else if (isTRUE(checkmate::check_numeric(variable$value, len = nrow(newdata)))) {
-        low <- x - variable$value / 2
-        high <- x + variable$value / 2
-        lab <- "custom"
-
     } else if (isTRUE(checkmate::check_numeric(variable$value, len = 2))) {
         variable$value <- sort(variable$value)
         low <- variable$value[1]
