@@ -1,4 +1,4 @@
-get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL, wts = NULL, ...) {
+get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL, wts = FALSE, ...) {
 
     # mice
     if (inherits(model, c("mira", "amest"))) {
@@ -12,6 +12,12 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
         return(NULL)
     }
 
+    # otherwise, insight::get_data can sometimes return only the the outcome variable
+    if (inherits(model, "bart")) {
+        modeldata <- insight::get_data(model, additional_variables = TRUE)
+        return(modeldata)
+    }
+
     if (!is.null(modeldata)) {
         modeldata <- set_variable_class(modeldata, model = model)
         return(modeldata)
@@ -55,20 +61,26 @@ get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL,
     }
 
     # always extract weights variable if available
-    wts <- hush(insight::find_weights(model))
-    if (isTRUE(checkmate::check_formula(wts))) {
-        additional_variables <- c(additional_variables, hush(all.vars(wts)))
-    } else if (isTRUE(checkmate::check_character(wts, max.len = 4))) {
-        if (isTRUE(grepl("~", wts))) {
-            additional_variables <- c(additional_variables, hush(all.vars(stats::as.formula(wts))))
+    wtsvname <- hush(insight::find_weights(model))
+    if (isTRUE(checkmate::check_formula(wtsvname))) {
+        additional_variables <- c(additional_variables, hush(all.vars(wtsvname)))
+    } else if (isTRUE(checkmate::check_character(wtsvname, max.len = 4))) {
+        if (isTRUE(grepl("~", wtsvname))) {
+            additional_variables <- c(additional_variables, hush(all.vars(stats::as.formula(wtsvname))))
         } else {
-            additional_variables <- c(additional_variables, wts)
+            additional_variables <- c(additional_variables, wtsvname)
         }
     }
 
-
     out <- hush(insight::get_data(model, verbose = FALSE, additional_variables = additional_variables))
 
+    if (isTRUE(wts)) {
+      tmp <- insight::get_weights(model)
+      if (is.numeric(tmp) && length(tmp) == nrow(out)) {
+        out[["marginaleffects_wts_internal"]] <- tmp
+      }
+    }
+
     # iv_robust and some others
     if (is.null(out)) {
         out <- evalup(model[["call"]][["data"]])
