@@ -3,8 +3,6 @@
 #' @export
 get_predict.mhurdle <- function(model,
                                 newdata = insight::get_data(model),
-                                vcov = NULL,
-                                conf_level = 0.95,
                                 type = "response",
                                 ...) {
 
