@@ -27,6 +27,8 @@ utils::globalVariables(c(
 "..w",
 "marginaleffects_lab",
 "marginaleffects_ter",
+"..label_columns",
+"marginaleffects_internal_label",
 ".",
 "tmp_idx",
 "comparison",
@@ -61,6 +63,8 @@ utils::globalVariables(c(
 "predicted",
 "rowid",
 "rowidunique",
+"hi",
+"lo",
 "section",
 "stars_note",
 "statistic",
