@@ -127,6 +127,7 @@ print.marginaleffects <- function(x,
         "group" = "Group",
         "term" = "Term",
         "contrast" = "Contrast",
+        "hypothesis" = "Hypothesis",
         "value" = "Value",
         "by" = "By",
         "estimate" = "Estimate",
@@ -173,6 +174,7 @@ print.marginaleffects <- function(x,
         nd <- attr(x, "newdata_newdata")
     }
     tmp <- c("by",
+        attr(x, "hypothesis_by"),
         attr(nd, "variables_datagrid"),
         attr(nd, "newdata_variables_datagrid"),
         attr(x, "variables_datagrid"),
@@ -227,6 +229,14 @@ print.marginaleffects <- function(x,
         }
     }
 
+    print_columns_text <- print_type_text <- NULL
+    if (ncol(x) <= ncols && isTRUE(column_names)) {
+        print_columns_text <- paste("Columns:", paste(colnames(x), collapse = ", "), "\n")
+    }
+    if (isTRUE(type) && !is.null(attr(x, "type"))) {
+        print_type_text <- paste("Type: ", attr(x, "type"), "\n")
+    }
+
     if (style %in% c("tinytable", "html", "latex", "typst", "markdown")) {
         insight::check_if_installed("tinytable")
 
@@ -239,7 +249,10 @@ print.marginaleffects <- function(x,
         # at <- attributes(tab)
         # attributes(tab) <- at[names(at) %in% c("row.names", "names", "class")]
 
-        tab <- tinytable::tt(tab)
+        args <- list(x = tab)
+        notes <- c(print_type_text, print_columns_text)
+        if (!is.null(notes)) args$notes <- notes
+        tab <- do.call(tinytable::tt, args)
         tab <- tinytable::format_tt(tab, escape = TRUE)
 
         if (isTRUE(splitprint)) {
@@ -279,10 +292,12 @@ print.marginaleffects <- function(x,
         print(out, row.names = FALSE)
     }
     cat("\n")
-    # cat("Model type: ", attr(x, "model_type"), "\n")
-    # if (!inherits(x, "hypotheses.summary") && isTRUE(getOption("marginaleffects_print_type", default = TRUE))) {
-    #     cat("Prediction type: ", attr(x, "type"), "\n")
-    # }
+
+
+    cat(print_columns_text)
+    cat(print_type_text)
+    cat("\n")
+
     ## This is tricky to extract nicely when transform_* are passed from avg_comparisons to comparisons. I could certainly figure it out, but at the same time, I don't think the print method should return information that is immediately visible from the call. This is different from `type`, where users often rely on the default value, which can change from model to model, so printing it is often
     # if (!is.null(attr(x, "comparison_label"))) {
     #     cat("Pre-transformation: ", paste(attr(x, "comparison_label"), collapse = ""), "\n")
@@ -290,18 +305,6 @@ print.marginaleffects <- function(x,
     # if (!is.null(attr(x, "transform_label"))) {
     #     cat("Post-transformation: ", paste(attr(x, "transform_label"), collapse = ""), "\n")
     # }
-    vg <- attr(x, "variables_grid")
-    if (length(vg) > 0) {
-        cat(sprintf("Results averaged over levels of: %s",
-                    paste(vg, collapse = ", ")), "\n")
-    }
-    if (ncol(x) <= ncols && isTRUE(column_names)) {
-        cat("Columns:", paste(colnames(x), collapse = ", "), "\n")
-    }
-    if (isTRUE(type) && !is.null(attr(x, "type"))) {
-        cat("Type: ", attr(x, "type"), "\n")
-    }
-    cat("\n")
 
     print_tail <- attr(x, "print_tail")
     if (!is.null(print_tail)) {
